==> paraview-5.9.1-5-x86_64.pkg.tar.zst: usr/include/paraview/ParaView_paraview_plugins/vtkBagPlotViewsAndFiltersBagPlotModule.h <==

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H
#define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H

#ifdef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_STATIC_DEFINE
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT
#else
#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT
#    ifdef BagPlotViewsAndFiltersBagPlot_EXPORTS
        /* We are building this library */
#      define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT
#    define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_NO_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_NO_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_DEPRECATED
#    define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_DEPRECATED
#  endif
#endif

#endif /* VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H */

==> paraview-6.0.1-7-x86_64.pkg.tar.zst: usr/include/paraview/ParaView_paraview_plugins/vtkBagPlotViewsAndFiltersBagPlotModule.h <==

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H
#define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H

#ifdef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_STATIC_DEFINE
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT
#else
#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT
#    ifdef BagPlotViewsAndFiltersBagPlot_EXPORTS
        /* We are building this library */
#      define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT
#    define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#endif

#ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_NO_EXPORT
#  define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED_NO_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_EXPORT VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_DEPRECATED
#    define VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkBagPlotViewsAndFiltersBagPlotModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKBAGPLOTVIEWSANDFILTERSBAGPLOT_EXPORT_H */
